==> seedsui-react-5.5.1.tgz: package/es/DatePicker/RangeModal/RangeModal.js <==
var _excluded = ["separator", "caption", "min", "max", "type", "value", "StartComboProps", "EndComboProps", "visible", "onVisibleChange", "onChange", "onError"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useState, useEffect } from 'react';
import Modal from './../../Modal';
import InputDate from './../Combo';
import locale from './../../locale';
import DateModalUtils from './../Modal/Utils'; // 自定义时间

var RangeModal = forwardRef(function (_ref, ref) {
  var _ref$separator = _ref.separator,
      separator = _ref$separator === void 0 ? '' : _ref$separator,
      caption = _ref.caption,
      min = _ref.min,
      max = _ref.max,
      type = _ref.type,
      value = _ref.value,
      _ref$StartComboProps = _ref.StartComboProps,
      StartComboProps = _ref$StartComboProps === void 0 ? {} : _ref$StartComboProps,
      _ref$EndComboProps = _ref.EndComboProps,
      EndComboProps = _ref$EndComboProps === void 0 ? {} : _ref$EndComboProps,
      visible = _ref.visible,
      onVisibleChange = _ref.onVisibleChange,
      onChange = _ref.onChange,
      onError = _ref.onError,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  // 自定义日期数据
  var _useState = useState(null),
      startDate = _useState[0],
      setStartDate = _useState[1];

  var _useState2 = useState(null),
      endDate = _useState2[0],
      setEndDate = _useState2[1];

  useEffect(function () {
    initDate();
  }, [JSON.stringify(value)]); // 初始化数据

  function initDate() {
    if (Array.isArray(value) && value.length) {
      setStartDate(value[0]);
      setEndDate(value[1] || null);
    }
  } // 点击自定义取消


  function handleCancel() {
    if (onVisibleChange) onVisibleChange(false);
    initDate();
  } // 点击自定义确定


  function handleSubmit() {
    if (onChange) {
      onChange([startDate, endDate]);
    }
  } // 修改自定义开始时间


  function handleStartDate(value) {
    var newValue = DateModalUtils.validateDate(value, {
      type: type,
      min: min,
      max: max,
      onError: onError
    });
    if (newValue === false) return;
    setStartDate(newValue);
  } // 修改自定义结束时间


  function handleEndDate(value) {
    var newValue = DateModalUtils.validateDate(value, {
      type: type,
      min: min,
      max: max,
      onError: onError
    });
    if (newValue === false) return;
    setEndDate(newValue);
  }

  return /*#__PURE__*/React.createElement(Modal, _extends({
    ref: ref,
    visible: visible,
    captionProps: {
      caption: caption || ''
    },
    submitProps: {
      onClick: handleSubmit
    },
    cancelProps: {
      onClick: handleCancel
    }
  }, props), /*#__PURE__*/React.createElement(InputDate, _extends({
    type: type || 'date',
    max: endDate,
    value: startDate,
    onChange: handleStartDate,
    placeholder: locale('请选择'),
    className: "datepicker-modal-combo",
    ModalProps: {
      maskProps: {
        style: {
          zIndex: '11'
        }
      }
    }
  }, StartComboProps || {})), /*#__PURE__*/React.createElement(InputDate, _extends({
    type: type || 'date',
    min: startDate,
    value: endDate,
    onChange: handleEndDate,
    placeholder: locale('请选择'),
    className: "datepicker-modal-combo",
    ModalProps: {
      maskProps: {
        style: {
          zIndex: '11'
        }
      }
    }
  }, EndComboProps || {})));
});
export default RangeModal;

==> seedsui-react-5.5.5.tgz: package/es/DatePicker/RangeModal/RangeModal.js <==
var _excluded = ["separator", "caption", "min", "max", "type", "value", "StartComboProps", "EndComboProps", "visible", "onVisibleChange", "onChange", "onError"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useState, useEffect } from 'react';
import Modal from './../../Modal';
import InputDate from './../Combo';
import locale from './../../locale';
import DateModalUtils from './../Modal/Utils'; // 自定义时间

var RangeModal = forwardRef(function (_ref, ref) {
  var _ref$separator = _ref.separator,
      separator = _ref$separator === void 0 ? '' : _ref$separator,
      caption = _ref.caption,
      min = _ref.min,
      max = _ref.max,
      type = _ref.type,
      value = _ref.value,
      _ref$StartComboProps = _ref.StartComboProps,
      StartComboProps = _ref$StartComboProps === void 0 ? {} : _ref$StartComboProps,
      _ref$EndComboProps = _ref.EndComboProps,
      EndComboProps = _ref$EndComboProps === void 0 ? {} : _ref$EndComboProps,
      visible = _ref.visible,
      onVisibleChange = _ref.onVisibleChange,
      onChange = _ref.onChange,
      onError = _ref.onError,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  // 标题与日期范围
  var key = null;
  var range = null;

  if (Object.prototype.toString.call(visible) === '[object Object]') {
    var items = Object.entries(visible)[0];

    if (items && items.length === 2) {
      key = items[0];
      range = items[1];
    }
  } // 自定义日期数据


  var _useState = useState(null),
      startDate = _useState[0],
      setStartDate = _useState[1];

  var _useState2 = useState(null),
      endDate = _useState2[0],
      setEndDate = _useState2[1];

  useEffect(function () {
    if (visible) {
      initDate();
    }
  }, [JSON.stringify(visible)]); // 初始化数据

  function initDate() {
    if (Array.isArray(value) && value.length) {
      setStartDate(value[0]);
      setEndDate(value[1] || null);
      return;
    }

    if (Array.isArray(range) && range.length) {
      setStartDate(range[0]);
      setEndDate(range[1] || null);
    }
  } // 点击自定义取消


  function handleCancel() {
    if (onVisibleChange) onVisibleChange(false);
    initDate();
  } // 点击自定义确定


  function handleSubmit() {
    if (onChange) {
      onChange([startDate, endDate]);
    }
  } // 修改自定义开始时间


  function handleStartDate(value) {
    var newValue = DateModalUtils.validateDate(value, {
      type: type,
      min: min,
      max: max,
      onError: onError
    });
    if (newValue === false) return;
    setStartDate(newValue);
  } // 修改自定义结束时间


  function handleEndDate(value) {
    var newValue = DateModalUtils.validateDate(value, {
      type: type,
      min: min,
      max: max,
      onError: onError
    });
    if (newValue === false) return;
    setEndDate(newValue);
  }

  return /*#__PURE__*/React.createElement(Modal, _extends({
    ref: ref,
    visible: visible,
    captionProps: {
      caption: key || caption || ''
    },
    submitProps: {
      onClick: handleSubmit
    },
    cancelProps: {
      onClick: handleCancel
    }
  }, props), /*#__PURE__*/React.createElement(InputDate, _extends({
    type: type || 'date',
    max: endDate,
    value: startDate,
    onChange: handleStartDate,
    placeholder: locale('请选择'),
    className: "datepicker-modal-combo",
    ModalProps: {
      maskProps: {
        style: {
          zIndex: '11'
        }
      }
    }
  }, StartComboProps || {})), /*#__PURE__*/React.createElement(InputDate, _extends({
    type: type || 'date',
    min: startDate,
    value: endDate,
    onChange: handleEndDate,
    placeholder: locale('请选择'),
    className: "datepicker-modal-combo",
    ModalProps: {
      maskProps: {
        style: {
          zIndex: '11'
        }
      }
    }
  }, EndComboProps || {})));
});
export default RangeModal;
